##
##  swig.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         swig
Summary:      Scripting Language Interface Compiler for C/C++
URL:          http://www.swig.org/
Vendor:       D.M. Beazley
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        CompilerCompiler
License:      BSD-style
Version:      4.3.0
Release:      20241021

#   list of sources
Source0:      http://downloads.sourceforge.net/swig/swig-%{version}.tar.gz
Patch0:       swig.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, make, libtool
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  pcre
PreReq:       pcre

%description
    SWIG is an interface compiler that connects programs written in
    C, C++, and Objective-C with scripting languages including Perl,
    Python, and Tcl/Tk. It works by taking the declarations commonly
    found in C/C++ header files and using them to generate the glue code
    (wrappers) that scripting languages need to access the underlying
    C/C++ code.

%track
    prog swig = {
        version   = %{version}
        url       = http://sourceforge.net/projects/swig/files/
        regex     = swig-(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lpcre" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --with-swiglibdir=%{l_prefix}/libexec/swig \
        --disable-ccache \
        --disable-shared \
        --without-x
    %{l_make} %{l_mflags}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

